@@ -114,34 +114,38 @@ def _files(source):
     else :
          yield open(source, 'rb')
 
-def put(source, dest, use_sudo=False):
-    tmp = uuid.uuid1()
-    tmpsourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
-    tar(source, tmpsourcepath)
+def put(source, dest, tar=False, *args, **kwargs):
+    if tar:
+        tmp = uuid.uuid1()
+        tmpsourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
+        tar(source, tmpsourcepath)
 
     with settings(warn_only=True):
-        api.put(tmpsourcepath, dest, use_sudo)
+        api.put(tmpsourcepath, dest, *args, **kwargs)
 
-    tmpdestpath = "%s/%s.tar.gz" % (dest, tmp)
-    untar(tmpdestpath, dest, local=False)
+    if tar:
+        tmpdestpath = "%s/%s.tar.gz" % (dest, tmp)
+        untar(tmpdestpath, dest, local=False)
 
-    local('rm -fr %s' % tmpsourcepath)
-    run('rm -fr %s' % tmpdestpath)
+        local('rm -fr %s' % tmpsourcepath)
+        run('rm -fr %s' % tmpdestpath)
 
 
-def get(source, dest, use_sudo=False):
-
-    tmp = uuid.uuid1()
-    tmpsourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
-    tar(source, tmpsourcepath, local_use=False)
+def get(source, dest, tar=False, *args, **kwargs):
+    if tar:
+        tmp = uuid.uuid1()
+        tmpsourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
+        tar(source, tmpsourcepath, local_use=False)
 
     with settings(warn_only=True):
-        api.get(tmpsourcepath, dest, use_sudo)
+        api.get(tmpsourcepath, dest, *args, **kwargs)
 
-    tmpdestpath = "%s/%s.tar.gz" % (dest, tmp)
+    if tar:
+        tmpdestpath = "%s/%s.tar.gz" % (dest, tmp)
+        untar(tmpdestpath, dest)
 
-    local('rm -fr %s' % tmpdestpath)
-    run('rm -fr %s' % tmpsourcepath)
+        local('rm -fr %s' % tmpdestpath)
+        run('rm -fr %s' % tmpsourcepath)
 
 def firewall(flag=True):
     #/usr/sbin/
